/*
*
* This file is part of xVideoServiceThief,
* an open-source cross-platform Video service download
*
* Copyright (C) 2007 - 2009 Xesc & Technology
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with xVideoServiceThief. If not, see <http://www.gnu.org/licenses/>.
*
* Contact e-mail: Xesc <xeskuu.xvst@gmail.com>
* Program URL   : http://xviservicethief.sourceforge.net/
*
*/

function RegistVideoService()
{
	this.version = "1.0.0";
	this.minVersion = "2.0.0a";
	this.author = "Xesc & Technology 2009";
	this.website = "http://www.bebo.com/";
	this.ID = "bebo.com";
	this.caption = "Bebo";
	this.adultContent = false;
	this.aduiSite = false;
}

function getVideoInformation(url)
{
	// download webpage
	var http = new Http();
	var html = http.downloadWebpage(url);
	// check if is an embeded youtube video
	if (strIndexOf(html, "http://www.youtube.com/") != -1)
		return getVideoFromYoutube(html);
	else if (strIndexOf(html, "http://www.motionbox.com/") != -1) // check if is a embeded motionbox video
		return getVideoFromMotionbox(html);
	else // unknown video source
		return new VideoDefinition();
}

function getVideoFromYoutube(html)
{
	// check if youtube plugin is installed
	if (isPluginInstalled("youtube") == true)
	{
		var youtubeUrl = copyBetween(html, "http://www.youtube.com/", "&quot;");
		return executePlugin("youtube", "http://www.youtube.com/" + youtubeUrl);
	}
	else // youtube plugin not installed
		return new VideoDefinition();
}

function getVideoFromMotionbox(html)
{
	const URL_GET_PREXML = "http://www.motionbox.com/external/hd_player/type=hd,video_uid=%1,autoPlay=true";
	const URL_GET_XML = "http://www.motionbox.com/v1/videos/%1/player_manifest.xml?api_privacy_token=%2&country%5Fcode=US&referrer=%3";
	// init result
	var result = new VideoDefinition();
	// get the video title
	result.title = copyBetween(html, "<h3>", "</h3>");
	// get video_uid
	var video_uid = copyBetween(html, "mbox_player_", "&");
	// download pre-xml
	var http = new Http();
	var preXml = http.downloadWebpage(strFormat(URL_GET_PREXML, video_uid));
	// get api_privacy_token
	var api_privacy_token = copyBetween(preXml, "api_privacy_token%3D", "\"");
	// referrer
	var referrerBlock = copyBetween(html, "<div class=\"video-main\">", "</iframe>");
	var referrer = cleanUrl(copyBetween(referrerBlock, "src=\"", "\""));
	// get final xml
	var xml = http.downloadWebpage(strFormat(URL_GET_XML, video_uid, api_privacy_token, referrer));
	// get flv url
	result.URL = copyBetween(xml, "<hd-url>", "</hd-url>");
	// return the video information
	return result;
}

function getVideoServiceIcon()
{
	return new Array(
		0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
		0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,0xf3,0xff,
		0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,
		0x13,0x01,0x00,0x9a,0x9c,0x18,0x00,0x00,0x02,0x3a,0x49,0x44,0x41,0x54,0x38,0x11,
		0x6d,0x53,0x21,0x6b,0x5b,0x51,0x18,0x3d,0x09,0x97,0xf2,0x08,0x97,0x10,0x46,0x18,
		0x11,0x11,0x11,0x13,0x11,0x91,0x15,0x13,0x11,0x15,0x11,0x13,0x61,0x44,0x84,0x31,
		0x59,0x51,0xd1,0x1f,0x30,0x31,0x31,0x31,0x31,0x51,0x39,0x11,0x31,0x31,0x59,0x51,
		0x46,0x19,0x63,0x8c,0x51,0x31,0x46,0x99,0x8a,0x18,0xa3,0x32,0xa2,0xa2,0x22,0x94,
		0x50,0x1e,0xe1,0x31,0x2e,0xe5,0x8a,0x0b,0xd9,0x39,0xdf,0xdb,0x0b,0xed,0xd8,0x0d,
		0x37,0xf7,0xe6,0xe6,0x9c,0xf3,0x9d,0xf3,0xdd,0xf7,0x6a,0xf8,0xcf,0xf8,0xde,0x68,
		0x6c,0x3a,0xce,0xd9,0x3f,0x91,0xdf,0x31,0x25,0xe4,0x5c,0x9f,0xde,0xde,0xd6,0xfe,
		0x85,0xdf,0x3b,0x10,0x71,0xd7,0x7b,0x64,0x70,0x08,0x29,0x72,0x02,0xc9,0x3e,0x5a,
		0x81,0x9c,0x42,0x2b,0xae,0xcf,0xee,0x08,0xd5,0x2b,0xc5,0x5f,0xcd,0xe6,0x66,0xe8,
		0x5b,0xc0,0xf4,0x39,0xf2,0x18,0x50,0x10,0x1c,0x48,0x0b,0x04,0x14,0x64,0xaf,0xf8,
		0xbb,0xe0,0x3e,0xe3,0xfc,0xc0,0x42,0x15,0xcf,0x04,0x54,0x79,0x90,0x79,0x84,0xc9,
		0x18,0x7e,0xf6,0x16,0x38,0x38,0x80,0xac,0xab,0x6a,0x69,0xbf,0x8c,0x40,0x0d,0x68,
		0xde,0x15,0xb1,0xa0,0xb2,0x1d,0x62,0x44,0x6a,0xb5,0x4d,0x38,0x11,0x25,0x72,0x1a,
		0x0e,0xe1,0xf7,0xf6,0x80,0xcb,0x4b,0xa4,0x4f,0x5f,0x80,0x20,0x0f,0x60,0x40,0xc0,
		0xdb,0x8e,0x7b,0x55,0x77,0xca,0xac,0x9a,0xcc,0xad,0x91,0x28,0xa6,0x08,0xbd,0xc3,
		0x43,0x74,0xc7,0xe3,0xf2,0xec,0x28,0x60,0xf1,0xf2,0x05,0x56,0xc7,0xc7,0x5b,0x81,
		0xaf,0xe4,0xd6,0xd5,0xed,0x48,0xa2,0x59,0x26,0x51,0x23,0x84,0xc0,0x86,0x01,0x3f,
		0xd9,0x8f,0x6f,0xa3,0x11,0xe6,0x8c,0x94,0x88,0xe9,0xcf,0x66,0x68,0xd3,0x95,0x22,
		0x38,0xf2,0xd8,0x31,0x58,0x0f,0xd4,0x6d,0x51,0x23,0x05,0x34,0x43,0xa7,0x43,0x00,
		0xd0,0xe2,0xcc,0xe6,0x73,0xc4,0x93,0x13,0xcc,0x49,0x54,0xb4,0x0e,0x5d,0x29,0x82,
		0xc5,0x20,0xc8,0x89,0x98,0x31,0xb1,0x65,0x26,0x59,0x20,0x64,0xbc,0x48,0x2e,0x9e,
		0x28,0x01,0x35,0xe2,0x72,0x89,0xe2,0xfc,0x1c,0x9e,0x8e,0xe4,0xc0,0x5c,0x70,0x75,
		0xea,0x72,0xb2,0x18,0x04,0x5d,0x5d,0x99,0x03,0x11,0xaa,0x91,0xc9,0x0a,0x31,0x12,
		0x04,0x9b,0x1d,0xf3,0x9c,0xc2,0x0e,0x3a,0x57,0xad,0xba,0x9e,0x30,0xfd,0xa7,0x3b,
		0xcf,0x2f,0x2e,0xac,0x52,0x6f,0x7f,0x9f,0xfe,0x7d,0xe9,0x4a,0x28,0x0e,0xff,0x78,
		0x17,0xae,0xdf,0x47,0x3a,0x3b,0xb3,0xea,0x12,0x91,0x6f,0x7b,0x12,0x7f,0xb0,0x9b,
		0xe5,0x05,0x01,0xed,0xd1,0x13,0x3c,0x7a,0xff,0x0e,0xa9,0x28,0x10,0x4e,0x4f,0xe1,
		0x8a,0x00,0xd7,0xeb,0x22,0x9b,0x4e,0xed,0x2c,0x9b,0x4c,0x80,0xe5,0x0a,0x9e,0x31,
		0x77,0x6e,0xae,0x6b,0x26,0xa0,0x27,0xab,0xca,0xa4,0xb5,0x45,0x91,0xf6,0xeb,0x57,
		0xc8,0xba,0x5d,0xab,0x6e,0x5f,0x6c,0xa6,0x7f,0x73,0x04,0xb7,0x58,0xd0,0x4e,0xc6,
		0x9b,0x8a,0x78,0xf0,0x7b,0x5d,0x0a,0x08,0xf0,0x71,0xa7,0xb1,0x51,0xd7,0xd5,0xb4,
		0x6a,0xfa,0xc1,0x00,0x99,0xde,0x0d,0x55,0x5c,0x2d,0x2d,0xb7,0x63,0xe5,0x18,0x13,
		0x1a,0xeb,0x1b,0x2b,0x7e,0xef,0x65,0xfa,0x4c,0x27,0xba,0xdb,0x16,0xf3,0x49,0xa4,
		0xea,0xb6,0x1a,0xe6,0x1d,0x7f,0xf1,0x50,0xd7,0xdc,0x5c,0xaf,0xb7,0xbc,0xed,0x86,
		0xf8,0xed,0x50,0x4f,0x24,0xa2,0xc7,0x55,0x64,0xbb,0x01,0xee,0x1f,0xd2,0xf2,0x16,
		0xf4,0x77,0xf3,0x07,0xbb,0xff,0xfc,0xc0,0xdb,0xb0,0xc3,0xdc,0x00,0x00,0x00,0x00,
		0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82);
}
