/*
*
* This file is part of xVideoServiceThief,
* an open-source cross-platform Video service download
*
* Copyright (C) 2007 - 2009 Xesc & Technology
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with xVideoServiceThief. If not, see <http://www.gnu.org/licenses/>.
*
* Contact e-mail: Xesc <xeskuu.xvst@gmail.com>
* Program URL   : http://xviservicethief.sourceforge.net/
*
*/

function RegistVideoService()
{
	this.version = "1.0.3";
	this.minVersion = "2.0.0a";
	this.author = "Xesc & Technology 2009";
	this.website = "http://www.caught-on-video.com/";
	this.ID = ".caught-on-video.com";
	this.caption = "Caught On Video";
	this.adultContent = false;
	this.musicSite = false;
}

function getVideoInformation(url)
{
	// video information
	var result = new VideoDefinition();
	// download xml
	var http = new Http();
	var html = http.downloadWebpageEx(url, false);
	// check if is an embeded youtube video
	if (strIndexOf(html, "http://www.youtube.com/") != -1)
		return getVideoFromYoutube(html);
	else if (strIndexOf(html, "http://www.veoh.com/") != -1)
		return getVideoFromVeoh(html);
	else if (strIndexOf(html, "http://www.dailymotion.com/") != -1)
		return getVideoFromDailymotion(html);
	else
		return new VideoDefinition();
}

function getVideoFromYoutube(html)
{
	// check if youtube plugin is installed
	if (isPluginInstalled("youtube") == true)
	{
		var youtubeUrl = copyBetween(html, 'SWFObject("', '"');
		youtubeUrl = strReplace(youtubeUrl, "&amp;", "&");
		return executePlugin("youtube", youtubeUrl);
	}
	else // youtube plugin not installed
		return new VideoDefinition();
}

function getVideoFromVeoh(html)
{
	// check if youtube plugin is installed
	if (isPluginInstalled("veoh") == true)
	{
		var veohUrl = copyBetween(html, 'SWFObject("', '"');
		veohUrl = strReplace(veohUrl, "&amp;", "&");
		return executePlugin("veoh", veohUrl);
	}
	else // youtube plugin not installed
		return new VideoDefinition();
}

function getVideoFromDailymotion(html)
{
	const VIDEO_URL = "http://www.dailymotion.com/video/";
	// check if youtube plugin is installed
	if (isPluginInstalled("dailymotion") == true)
	{
		var videoId = copyBetween(html, 'SWFObject("', '"');
		videoId = copyBetween(videoId, "swf/", "?");
		return executePlugin("dailymotion", VIDEO_URL + videoId);
	}
	else // youtube plugin not installed
		return new VideoDefinition();
}

function getVideoServiceIcon()
{
	return new Array(
		0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
		0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,0xf3,0xff,
		0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,
		0x13,0x01,0x00,0x9a,0x9c,0x18,0x00,0x00,0x02,0x8f,0x49,0x44,0x41,0x54,0x38,0x11,
		0x8d,0x53,0x4d,0x4f,0x13,0x41,0x18,0x7e,0x76,0xf6,0xa3,0x94,0x96,0xdd,0x7e,0xa4,
		0x96,0xda,0x12,0x3f,0x90,0x68,0xf8,0x50,0x4b,0x62,0x62,0xa2,0x3d,0xe0,0xdd,0x3f,
		0x61,0xfc,0x13,0x1e,0x3c,0x9a,0x78,0xf2,0x6e,0x38,0xfa,0x03,0x3c,0xe1,0x45,0x83,
		0x17,0x14,0xd0,0x83,0x0a,0x4d,0x1b,0x74,0xa9,0x42,0x04,0x85,0xb6,0xb4,0x94,0x6e,
		0xdb,0x6d,0xbb,0xbb,0xce,0xbc,0xa5,0x2b,0xf1,0xe4,0x9b,0xec,0xcc,0xec,0xcc,0xf3,
		0x3e,0xf3,0xcc,0x3b,0xcf,0x48,0x9e,0xe7,0x39,0x38,0x0d,0xd7,0x75,0xd1,0x6c,0x36,
		0xb1,0xb3,0xb3,0x8b,0x4a,0xb9,0x8c,0x6e,0xaf,0x0f,0x45,0x61,0x88,0xc7,0x62,0xb8,
		0x70,0xf1,0x12,0x0c,0x43,0x07,0x63,0x6c,0x08,0xa7,0x5e,0x1a,0x12,0x74,0xbb,0x5d,
		0x94,0x4a,0x25,0x98,0xdf,0x4c,0x48,0x1c,0xa4,0xeb,0x3a,0x42,0xa1,0x10,0x2c,0xab,
		0x89,0x46,0xa3,0x81,0x7e,0xbf,0x8f,0x89,0x4c,0x06,0xb3,0x73,0x73,0xd0,0x34,0xcd,
		0x27,0x21,0x02,0xdb,0xb6,0xb1,0xb6,0xb6,0x8e,0x5a,0xad,0x86,0x89,0x89,0x0c,0xae,
		0x5e,0x99,0x84,0xbb,0xfa,0x1c,0xbd,0xfc,0x32,0xd4,0xd9,0x7b,0xe8,0xdd,0x7a,0xc8,
		0xc9,0xbf,0x63,0x6f,0x6f,0x0f,0x23,0x23,0x01,0x2c,0x2c,0x2c,0x20,0x10,0x08,0x0c,
		0x14,0x70,0x66,0xc7,0x34,0x4d,0x6c,0x6d,0x7d,0x45,0x2e,0x77,0x97,0x4b,0x56,0x00,
		0x73,0x19,0xc7,0xcf,0x1e,0x10,0x40,0x1e,0xed,0x23,0xfa,0x64,0x03,0x96,0x14,0x46,
		0xaf,0xd7,0xc3,0xfa,0xfa,0x07,0x44,0xf9,0x51,0xee,0xe4,0x72,0x90,0x65,0x19,0x4c,
		0x9c,0xd9,0x34,0xb7,0x91,0xcd,0x66,0x39,0xfb,0x08,0x4d,0xaa,0xc9,0x29,0xc8,0x31,
		0x9d,0x08,0xb4,0xa9,0xdb,0x68,0xcb,0x83,0xb1,0xaa,0xaa,0x98,0x99,0x99,0x46,0xb9,
		0x52,0xe5,0x35,0x3a,0xa4,0x75,0xe5,0xe0,0xe0,0x80,0x06,0xc9,0xe4,0x39,0xea,0x45,
		0xe3,0xc5,0x27,0x11,0x79,0x5a,0x00,0xcb,0xbf,0x44,0xf7,0xda,0x7d,0x38,0x8e,0x03,
		0x49,0x92,0xc0,0xeb,0x85,0x48,0x24,0x02,0x2d,0xa0,0x61,0x73,0x63,0x13,0xc9,0xf1,
		0x14,0x58,0x85,0xb3,0xc5,0xe3,0x71,0xaa,0x2e,0x49,0xe2,0x05,0x14,0x95,0x76,0x3e,
		0xbe,0x80,0xb5,0xf1,0x16,0xf2,0xee,0x2a,0xfd,0x8b,0x39,0x41,0x22,0x3e,0xc3,0x88,
		0xa0,0xca,0xf3,0x44,0x28,0xb6,0xdd,0x41,0x22,0x91,0x20,0xd0,0x70,0x97,0x4e,0xf1,
		0x0d,0xea,0x8b,0x8f,0x08,0xd0,0xcd,0xbf,0x46,0xf4,0xf1,0x7b,0x74,0xe4,0x90,0xaf,
		0x22,0x18,0x0c,0xd2,0xad,0x08,0x00,0x13,0xe7,0xb2,0xac,0x96,0x4f,0x20,0x76,0x72,
		0xab,0x3f,0x28,0x99,0x8d,0xba,0xf0,0x5a,0x35,0xbe,0x4b,0x95,0x92,0x69,0x92,0x37,
		0xed,0x76,0x1b,0x90,0x06,0x7f,0x2c,0x1a,0x8d,0xa1,0x5a,0x1d,0xc8,0x19,0x02,0x86,
		0xbd,0x04,0x17,0xaa,0xe2,0x71,0x72,0xd9,0x97,0x2f,0x54,0xd6,0xeb,0x75,0xe8,0x63,
		0x63,0x04,0x63,0x99,0x4c,0x1a,0xc2,0x81,0x65,0xee,0xbc,0xb3,0xa1,0xa9,0x0e,0x25,
		0x9f,0x9d,0x13,0xe3,0x5a,0xad,0x8e,0x96,0x65,0xe1,0xe6,0xfc,0x3c,0x2d,0xb1,0x70,
		0x38,0x8c,0x74,0x3a,0x45,0x46,0x12,0xf7,0x2c,0x42,0x0d,0x86,0xa9,0xff,0xb7,0x11,
		0x6e,0xcc,0xe7,0xf3,0x38,0x39,0x69,0x60,0x3c,0x95,0xa2,0x65,0x26,0x2a,0x3f,0x3d,
		0x3d,0xc3,0xed,0xa9,0x62,0x69,0xe9,0x15,0x0a,0x85,0x82,0x9f,0xe7,0xb6,0x07,0xbe,
		0xf7,0x98,0x42,0x5e,0x59,0x59,0x79,0x47,0x57,0x6a,0x70,0x9b,0x6f,0x73,0xef,0x88,
		0xf0,0xdf,0x82,0xb0,0xf3,0x97,0x4f,0x9f,0xf1,0x73,0x7f,0x1f,0x97,0x93,0xfc,0xae,
		0x2b,0x45,0x9f,0xa8,0xe4,0x24,0x71,0xdc,0xea,0xc0,0x08,0x87,0x70,0x83,0x4b,0xff,
		0xcd,0xbd,0xd3,0xb1,0xfb,0x48,0xc4,0xa3,0x7f,0x09,0x04,0x5a,0xd4,0xe2,0xe8,0xe8,
		0x08,0x45,0xae,0x42,0xf8,0xc3,0x3e,0x3d,0x92,0xa1,0x8f,0xe1,0xfa,0xdc,0x2c,0x52,
		0xe7,0xd3,0xf4,0x5a,0x45,0x1d,0x0e,0x0f,0x07,0x24,0xbe,0x02,0x7f,0xbb,0xff,0x18,
		0x88,0xd7,0x29,0x48,0x7e,0x71,0x25,0x7f,0x00,0x4f,0x85,0x26,0x67,0xd6,0x90,0xc0,
		0x81,0x00,0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82);
}
