/*
*
* This file is part of xVideoServiceThief,
* an open-source cross-platform Video service download
*
* Copyright (C) 2007 - 2009 Xesc & Technology
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with xVideoServiceThief. If not, see <http://www.gnu.org/licenses/>.
*
* Contact e-mail: Xesc <xeskuu.xvst@gmail.com>
* Program URL   : http://xviservicethief.sourceforge.net/
*
*/

function RegistVideoService()
{
	this.version = "2.0.3";
	this.minVersion = "2.0.0a";
	this.author = "Xesc & Technology 2009";
	this.website = "http://video.google.com/";
	this.ID = "video.google.";
	this.caption = "Google Video";
	this.adultContent = false;
	this.musicSite = false;
}

function getVideoInformation(url)
{
	const URL_GET_SHEET = "http://video.google.com/videohosted?docid=%1";
	// init result
	var result = new VideoDefinition();
	// get the docid
	var docid = getUrlParam(url, "docid");
	// get the video-sheet
	var http = new Http();
	var html = http.downloadWebpage(strFormat(URL_GET_SHEET, docid));
	// get video title
	result.title = copyBetween(html, "<title>", "</title>");
	// delete the google video tag
	result.title = strReplace(result.title, "- Google Video", "");
	// get flv url
	result.URL = copyBetween(html, "videoUrl", "\\");
	// get the separator token
	var sep = strIndexOf(result.URL, "http");
	result.URL = strRemove(result.URL, 0, sep);
	// clean the video URL
	result.URL = cleanUrl(result.URL);
	// return the video information
	return result;
}

function searchVideos(keyWord, pageIndex)
{
	const URL_SEARCH = "http://video.google.com/videosearch?q=%1&start=%2&hl=%3";
	const HTML_SEARCH_START = '<div class=tv-res id=search-results>';
	const HTML_SEARCH_FINISH = "<div style=clear:both;></div>";
	const HTML_SEARCH_SEPARATOR = "<div class=rl-item>";
	// replace all spaces for "+"
	keyWord = strReplace(keyWord, " ", "+");
	pageIndex = (pageIndex - 1) * 10;
	// init search results object
	var searchResults = new SearchResults();
	// init http object
	var http = new Http();
	var html = http.downloadWebpage(strFormat(URL_SEARCH, keyWord, pageIndex, searchResults.getUserLanguage()), false);
	// get the search summary
	searchResults.setSummary(copyBetween(html, "<span class=results_summary id=summary>", "</span>"));
	// get results html block
	var htmlResults = copyBetween(html, HTML_SEARCH_START, HTML_SEARCH_FINISH);
	// if we found some results then...
	if (htmlResults != "")
	{
		var block = "";
		// iterate over results
		while ((block = copyBetween(htmlResults, HTML_SEARCH_SEPARATOR, HTML_SEARCH_SEPARATOR)) != "")
		{
			parseResultItem(searchResults, block);
			htmlResults = strRemove(htmlResults, 0, block.toString().length);
		}
		// get last result
		parseResultItem(searchResults, htmlResults);
	}
	// return search results
	return searchResults;
}

function parseResultItem(searchResults, html)
{
	var videoUrl, imageUrl, title, description, duration, rating;
	// get info from html block
	videoUrl = copyBetween(html, "srcurl=", ">");
	imageUrl = copyBetween(copyBetween(html, "img class=thumbnail-img", "</a>"), "src=", ">");
	title = copyBetween(html, "<div class=rl-title>", "</div>");
	title = copyBetween(title, "target=_top>", "</a>");
	description = copyBetween(html, "<div class=rl-snippet>", "</div>");
	duration = copyBetween(html, "duration=", " ");
	rating = copyBetween(html, "<span class=rl-stars ratings=", ">");
	// add to results list
	searchResults.addSearchResult(videoUrl, imageUrl, title, description, duration, rating);
}

function getVideoServiceIcon()
{
	return new Array(
		0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
		0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,0xf3,0xff,
		0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,
		0x13,0x01,0x00,0x9a,0x9c,0x18,0x00,0x00,0x03,0x39,0x49,0x44,0x41,0x54,0x38,0x11,
		0x1d,0x93,0x4b,0x68,0x5c,0x55,0x18,0xc7,0x7f,0xf7,0xdc,0x3b,0xcf,0x4c,0x1e,0x33,
		0x99,0x69,0x13,0xda,0xd8,0xd8,0x19,0x69,0x50,0xb2,0x68,0x23,0x0a,0x41,0x1a,0xb0,
		0xda,0x76,0xe1,0x0b,0x94,0xe2,0xc2,0xda,0x82,0xa0,0x6e,0xd5,0x65,0xb7,0x55,0xbb,
		0x71,0xa3,0xb8,0x69,0x7d,0xe0,0x26,0x16,0x11,0x45,0x04,0x31,0x48,0x40,0xa8,0xad,
		0x0f,0x7c,0xc5,0xd6,0x18,0x9d,0x42,0x42,0xda,0x34,0x3a,0xc6,0x74,0x26,0x9d,0x99,
		0xcc,0xcc,0x7d,0x1c,0xff,0xb7,0x97,0x3b,0x73,0xee,0x3d,0x73,0xbe,0xff,0xf7,0xfd,
		0x1f,0x03,0xba,0xfc,0xc0,0xda,0x1f,0xab,0xab,0x76,0xfc,0xc4,0xac,0xf5,0x1e,0xf9,
		0xc0,0xbe,0xf6,0xf1,0x82,0x0d,0x6d,0x60,0xbb,0x8d,0x9b,0xf6,0xc2,0xcc,0xb4,0xfd,
		0xdd,0xc1,0xf6,0x8c,0xb1,0x21,0xe8,0x63,0x6c,0x5b,0xef,0x9b,0x7a,0x8e,0x6b,0x4d,
		0xe0,0x5b,0xeb,0xba,0x70,0xfa,0xfc,0x22,0x2b,0x9d,0x61,0xa2,0x9d,0xf7,0x70,0xe6,
		0x8b,0x7f,0x59,0x5e,0x6f,0x93,0xec,0xef,0x67,0xea,0xed,0x73,0x14,0xfa,0xb2,0xb8,
		0x51,0x84,0xe3,0xe8,0xa0,0x13,0xc5,0x75,0x44,0x78,0xac,0x18,0xac,0x71,0x3d,0x08,
		0x83,0x80,0x2b,0xff,0xe8,0x87,0xdc,0x20,0x91,0xd0,0xb6,0xb6,0x13,0x7c,0xf8,0xfd,
		0x8a,0x8e,0xb9,0xa4,0x27,0xee,0xa6,0x3b,0xfd,0x00,0x01,0x0e,0x91,0x09,0x6f,0xaf,
		0x3d,0xeb,0x62,0x9d,0x00,0xab,0x12,0x13,0x7f,0x79,0x8e,0xc7,0xce,0xa1,0x34,0xa6,
		0x17,0x61,0xe8,0x62,0xd4,0xe9,0xca,0x72,0xa0,0x6e,0x2a,0x53,0xd3,0xb0,0x3f,0x8b,
		0x2f,0x30,0x37,0x3e,0x6b,0x0d,0xae,0x13,0xd2,0x13,0x01,0xdf,0xb8,0xaa,0x35,0xda,
		0xd5,0x75,0x64,0xb2,0xc8,0xc5,0x3f,0xd6,0xf1,0x52,0x79,0xa2,0x48,0x20,0xc6,0xd3,
		0x98,0x2e,0xa6,0x0b,0xb5,0xc5,0x25,0xd6,0x46,0x0d,0x37,0xfb,0xf3,0x24,0x7a,0xb0,
		0xa3,0xde,0xa4,0xb4,0xe5,0xe3,0x4b,0x11,0xef,0xea,0x6a,0x9d,0xf2,0x1d,0x05,0x9e,
		0x3f,0x5a,0x61,0xf6,0xc2,0x35,0x96,0xfe,0x6e,0x30,0x90,0x89,0x38,0x39,0xb3,0x5b,
		0x43,0x3b,0x9c,0x9d,0x7b,0x87,0xd3,0x47,0x3a,0x5c,0xbb,0x6b,0xbf,0x3a,0x27,0x09,
		0xc3,0x88,0x4c,0xdb,0x67,0xff,0xd5,0x6d,0x9e,0xb8,0xb4,0x8a,0xb3,0xef,0xd9,0xf7,
		0xed,0xab,0x27,0xef,0xe7,0xc9,0x99,0x09,0xea,0x2d,0x9f,0xcf,0x7e,0x5a,0x63,0xba,
		0x3c,0x48,0x79,0x2c,0xcf,0x99,0xb9,0x73,0x9c,0xfa,0xe1,0x2d,0xdc,0x91,0x41,0xa9,
		0x66,0x09,0x23,0xf9,0x20,0x92,0x8e,0x2f,0x1b,0x4c,0x02,0xa7,0xe9,0xe2,0x94,0x8e,
		0x9d,0xb7,0x7e,0xb7,0xc9,0x81,0xf1,0x2c,0x0f,0x4e,0x8d,0x70,0xea,0x99,0x83,0xe2,
		0x6e,0xf9,0xba,0xfa,0x33,0x87,0xde,0x3d,0x46,0x54,0xd9,0xa1,0x62,0xa3,0x3d,0xdd,
		0xbd,0xc4,0x6d,0xba,0xd6,0x97,0x36,0x81,0x9e,0x03,0x07,0x53,0x70,0x7b,0xe4,0x92,
		0x69,0x2e,0x55,0x3b,0xbc,0x31,0xfb,0x17,0x2b,0xb5,0x16,0x32,0x96,0xbd,0x85,0x5d,
		0x54,0xca,0x07,0xa0,0xdb,0xc1,0x08,0xc0,0x84,0x9e,0x8c,0x57,0xa1,0x26,0x71,0x50,
		0x77,0x41,0x59,0xd3,0xc3,0xf8,0xf5,0x0d,0x76,0x67,0xba,0x3c,0x76,0x6f,0x91,0xe3,
		0x47,0x45,0x63,0x2b,0x94,0x45,0x30,0x36,0x3c,0xca,0xc5,0xa7,0xcf,0x72,0xb8,0x78,
		0x10,0xdb,0x6e,0x8a,0x81,0x36,0x05,0x1c,0xc5,0x8b,0x8a,0x85,0x23,0x1b,0x04,0x34,
		0xfb,0xd5,0xaf,0xf6,0xe1,0xa9,0x49,0x86,0xf3,0x86,0xa0,0xb1,0xc8,0xe6,0x7f,0x55,
		0xda,0x5b,0x37,0x18,0xad,0x3c,0x45,0x3a,0x57,0xc2,0x0f,0x03,0x1e,0xff,0xe8,0x65,
		0xbe,0x5c,0x9f,0xc7,0x26,0x07,0xe4,0xa9,0x9c,0xf1,0x23,0x22,0xad,0x48,0x12,0x47,
		0x99,0xb5,0xcd,0x8d,0x05,0xaa,0xdf,0xbe,0x48,0x9e,0xdf,0xf0,0x12,0x6d,0x6c,0xd7,
		0xd0,0xf4,0x27,0xd8,0x75,0xe8,0x53,0x06,0x0a,0x65,0x96,0x6a,0xd7,0xb9,0xef,0xbd,
		0x13,0xdc,0xca,0xf6,0x70,0x03,0x85,0x28,0x54,0xa8,0xc4,0x5f,0x8c,0x64,0x73,0xd4,
		0xe2,0xcf,0xf9,0x17,0xb8,0xd3,0xfb,0x8e,0x3d,0xa5,0x0e,0x23,0x03,0x59,0x8a,0x43,
		0x29,0x8a,0xce,0x22,0xb5,0x6f,0x5e,0xd2,0xb8,0x86,0x7d,0xc5,0x3d,0x8c,0xf4,0x49,
		0xcc,0xae,0x4f,0x28,0x81,0x63,0x33,0x12,0x12,0x51,0x39,0xc3,0xeb,0x35,0x6a,0xe4,
		0x82,0xeb,0xa4,0x13,0x43,0xdc,0x6a,0xc6,0xea,0x8a,0xa7,0x0e,0x64,0x33,0x05,0xc2,
		0xce,0x9a,0x2c,0x6b,0xb1,0x6d,0xfa,0xe8,0x34,0x5b,0x9a,0x37,0xa1,0x3f,0x4f,0x52,
		0x3a,0x08,0x48,0x21,0xb2,0x12,0xc2,0x64,0x86,0xc6,0x49,0x95,0x1e,0xa2,0xb5,0xa9,
		0x6c,0x77,0xb2,0x1a,0x2f,0xa9,0x78,0xe6,0x08,0xb7,0x5d,0x52,0xa3,0x8f,0x8a,0x77,
		0x8e,0xcf,0x7f,0x99,0xe3,0x46,0x63,0x1d,0x27,0x54,0x06,0x14,0x24,0x21,0x12,0x29,
		0xf6,0x44,0x3a,0x9b,0xf0,0x8c,0xe3,0x37,0x37,0x6c,0x7d,0x61,0x0c,0xdb,0xb8,0xac,
		0x8e,0x6d,0x7c,0x2f,0x4d,0xaa,0x72,0x98,0xf4,0xe4,0x73,0x5c,0x5e,0x5d,0xe6,0x95,
		0x4f,0xde,0x24,0xf4,0xe2,0x58,0x7b,0xd2,0x2d,0xb6,0x21,0x0e,0x94,0x72,0xf0,0xfa,
		0xbc,0xf3,0x3f,0xc9,0x90,0x7b,0x91,0x15,0x22,0xed,0xd7,0x00,0x00,0x00,0x00,0x49,
		0x45,0x4e,0x44,0xae,0x42,0x60,0x82);
}
