/*
*
* This file is part of xVideoServiceThief,
* an open-source cross-platform Video service download
*
* Copyright (C) 2007 - 2009 Xesc & Technology
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with xVideoServiceThief. If not, see <http://www.gnu.org/licenses/>.
*
* Contact e-mail: Xesc <xeskuu.xvst@gmail.com>
* Program URL   : http://xviservicethief.sourceforge.net/
*
*/

function RegistVideoService()
{
	this.version = "1.0.2";
	this.minVersion = "2.0.0a";
	this.author = "Xesc & Technology 2009";
	this.website = "http://www.vimeo.com/";
	this.ID = "vimeo.com";
	this.caption = "Vimeo";
	this.adultContent = false;
	this.musicSite = false;
}

function getVideoInformation(url)
{
	const URL_GET_XML = "http://vimeo.com/moogaloop/load/clip:%1/local?%2";
	const URL_GET_FLV = "http://vimeo.com/moogaloop/play/clip:%1/%2/%3/?q=sd";
	// init result
	var result = new VideoDefinition();
	// get videoId
	var videoId = getToken(url, ".com/", 1);
	// is a HD video?
	if (videoId.toString().indexOf("hd#") != -1)
	{
		videoId = getToken(url, "hd#", 1);
		result.extension = ".mp4";
	}
	// get the possible channel
	var channel_id = "";
	// download webpage
	var http = new Http();
	var html = http.downloadWebpage(url);
	// has a channel id?
	if (html.toString().indexOf('id="channel_id"') != -1) 
		channel_id = copyBetween(html, 'id="channel_id" value="', '"');
	// found the channel id?
	var channel_params = channel_id != "" ? "context=channel&context_id=" + channel_id : "";
	var xml = http.downloadWebpage(strFormat(URL_GET_XML, videoId, channel_params));
	// get video title
	result.title = copyBetween(xml, "<caption>", "</caption>");
	// get signature
	var signature = copyBetween(xml, "<request_signature>", "</request_signature>");
	// get signature expires
	var signature_expires = copyBetween(xml, "<request_signature_expires>", "</request_signature_expires>");
	// build the final flv url
	result.URL = strFormat(URL_GET_FLV, videoId, signature, signature_expires);
	// return the video information
	return result;
}

function getVideoServiceIcon()
{
	return new Array(
		0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
		0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x10,0x08,0x02,0x00,0x00,0x00,0x90,0x91,0x68,
		0x36,0x00,0x00,0x01,0x2f,0x69,0x43,0x43,0x50,0x49,0x43,0x43,0x20,0x50,0x72,0x6f,
		0x66,0x69,0x6c,0x65,0x00,0x00,0x78,0x01,0x63,0x60,0x60,0x32,0x70,0x74,0x71,0x72,
		0x65,0x12,0x60,0x60,0xc8,0xcd,0x2b,0x29,0x0a,0x72,0x77,0x52,0x88,0x88,0x8c,0x52,
		0x60,0xbf,0xc0,0xc0,0xc1,0xc0,0xcd,0x20,0xcc,0x60,0xcc,0x60,0x9d,0x98,0x5c,0x5c,
		0xe0,0x18,0x10,0xe0,0xc3,0x00,0x04,0x79,0xf9,0x79,0xa9,0x20,0x1a,0x15,0x7c,0xbb,
		0xc6,0xc0,0x08,0x12,0xb9,0xac,0x0b,0x32,0x0b,0x55,0x8e,0x20,0x8f,0x2b,0xb9,0xa0,
		0xa8,0x04,0xa8,0xea,0x0f,0x10,0x1b,0xa5,0xa4,0x16,0x27,0x33,0x30,0x30,0x1a,0x00,
		0xd9,0xd9,0xe5,0x25,0x05,0x40,0x71,0xc6,0x39,0x40,0xb6,0x48,0x52,0x36,0x98,0xbd,
		0x01,0xc4,0x2e,0x0a,0x09,0x72,0x06,0x8a,0x1f,0x01,0xb2,0xf9,0xd2,0x21,0xec,0x2b,
		0x20,0x76,0x12,0x84,0xfd,0x04,0xc4,0x2e,0x02,0x7a,0x02,0xa8,0xe6,0x0b,0x48,0x7d,
		0x3a,0x98,0xcd,0xc4,0x01,0x62,0x27,0x41,0xd8,0x32,0x20,0x76,0x49,0x6a,0x05,0xc8,
		0x5e,0x06,0xe7,0xfc,0x82,0xca,0xa2,0xcc,0xf4,0x8c,0x12,0x05,0x23,0x03,0x03,0x03,
		0x05,0xc7,0x94,0xfc,0xa4,0x54,0x85,0xe0,0xca,0xe2,0x92,0xd4,0xdc,0x62,0x05,0xcf,
		0xbc,0xe4,0xfc,0xa2,0x82,0xfc,0xa2,0xc4,0x92,0xd4,0x14,0xa0,0x5a,0x88,0xfb,0x40,
		0xba,0x18,0x04,0x21,0x0a,0x41,0x21,0xa6,0x61,0x68,0x69,0x69,0xa1,0x09,0x16,0xa5,
		0x22,0x01,0x8a,0x07,0x88,0x71,0x9f,0x03,0xc1,0xe1,0xcb,0x28,0x76,0x06,0x21,0x86,
		0xb0,0x28,0xb9,0xb4,0xa8,0x0c,0xca,0x63,0x64,0x32,0x66,0x60,0x20,0xc4,0x47,0x98,
		0x31,0x47,0x82,0x81,0xc1,0x7f,0x29,0x03,0x03,0xcb,0x1f,0x84,0x98,0x49,0x2f,0x03,
		0xc3,0x02,0x1d,0x06,0x06,0xfe,0xa9,0x08,0x31,0x35,0x43,0x06,0x06,0x01,0x7d,0x06,
		0x86,0x7d,0x73,0x00,0xc3,0xaf,0x50,0x6f,0xe6,0xb3,0xe5,0xe9,0x00,0x00,0x00,0x09,
		0x70,0x48,0x59,0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,0x13,0x01,0x00,0x9a,0x9c,
		0x18,0x00,0x00,0x01,0xc6,0x49,0x44,0x41,0x54,0x28,0x15,0x63,0xfc,0xf9,0xf3,0xd7,
		0x8a,0x67,0x5f,0xe7,0xdc,0x7b,0x7f,0xe1,0xc3,0x0f,0x06,0x1c,0x80,0x99,0x91,0xc1,
		0x40,0x80,0x33,0x4b,0x45,0xc8,0x5f,0x9c,0x93,0x71,0xc9,0x83,0x0f,0x99,0x67,0x9f,
		0xe1,0x50,0x89,0x2e,0xbc,0xc2,0x52,0x86,0xf9,0xb5,0x6f,0xda,0x8b,0x1f,0x7f,0xd0,
		0x65,0x70,0xf0,0x5f,0xff,0xfc,0xcb,0xf2,0xe6,0xd7,0x5f,0xb8,0xac,0x1e,0x3f,0xc7,
		0x87,0xdf,0x7f,0x1f,0x7d,0xfb,0x0d,0x11,0x91,0xe3,0x62,0x8d,0x96,0xe7,0xff,0xf8,
		0xfb,0xdf,0xd2,0x87,0x1f,0x3f,0xfe,0x06,0x29,0x7b,0xf3,0xf3,0x0f,0x0b,0x5c,0x75,
		0x87,0x9e,0x38,0xd0,0x95,0x1f,0x7f,0xfd,0xb5,0xde,0x77,0x1f,0xa8,0xc7,0x56,0x94,
		0x6b,0xab,0xad,0x3c,0x44,0x56,0x97,0x97,0x35,0xf3,0xfc,0x4b,0x08,0x9b,0x09,0x48,
		0xf1,0xb3,0x32,0x4f,0x37,0x96,0x02,0xaa,0x06,0xb1,0xd9,0x98,0x7d,0x84,0x59,0x81,
		0x8c,0x0c,0x69,0xce,0x0f,0x5f,0xbf,0x41,0x14,0xc9,0xfe,0x85,0x32,0x80,0x5c,0x90,
		0x06,0x5d,0x6e,0xa6,0xfb,0xd7,0xaf,0x5d,0xbc,0xf7,0x18,0x22,0x2d,0xf3,0xef,0x3b,
		0xd0,0x88,0xd0,0x9e,0x79,0x93,0x37,0xef,0x87,0x88,0x3c,0x78,0xf9,0x06,0xc2,0x00,
		0x92,0x20,0x0d,0x87,0xae,0xdf,0x6b,0x3b,0x72,0x3d,0x75,0xde,0x7a,0x88,0xa8,0x9e,
		0x08,0x2f,0xd0,0x6c,0x36,0x17,0x7f,0x03,0x7d,0x1d,0x88,0xc8,0x92,0xf3,0xb7,0x21,
		0x0c,0x20,0x09,0xd2,0xc0,0x24,0x29,0xcb,0x62,0x64,0x79,0x4d,0x5e,0xff,0x21,0xd8,
		0x24,0x3b,0x65,0x69,0x46,0x36,0x76,0xa0,0x1f,0x7c,0x35,0x41,0x7e,0xd8,0x78,0xfc,
		0xfc,0x31,0x46,0x7e,0x14,0x0d,0x10,0x0e,0x93,0xb0,0xd8,0xc1,0xeb,0xf7,0x21,0xec,
		0x4a,0x4d,0x91,0x76,0x4d,0x90,0x97,0x80,0x56,0xa5,0xaf,0x39,0x08,0x34,0x11,0x8b,
		0x06,0xa0,0xd0,0xe1,0x67,0xef,0x61,0x1a,0x44,0x81,0x0e,0x03,0xb2,0x43,0x3b,0x66,
		0x7d,0x35,0x75,0x80,0x08,0x42,0x48,0x90,0x93,0xe0,0x60,0xeb,0xab,0xef,0x70,0x36,
		0x90,0x91,0xdc,0x3f,0xff,0xb8,0x84,0x16,0xd0,0x79,0xc8,0x82,0x28,0x1a,0x3e,0x4b,
		0xc8,0x4f,0xda,0xb0,0x1b,0x28,0x0d,0x74,0x09,0x50,0xf5,0x8a,0x9f,0xbc,0xc8,0x8e,
		0x81,0x68,0x63,0x51,0xe0,0x62,0x7d,0x02,0x8b,0x5a,0xa0,0x61,0xe5,0xc7,0x6e,0x6f,
		0x3a,0x71,0xe1,0xd2,0x93,0x97,0x5f,0x75,0x2c,0x98,0xd5,0xb4,0x91,0xcd,0x06,0xb2,
		0xe5,0xb9,0xd9,0x18,0x37,0x3d,0xfd,0x14,0x7d,0xe2,0x09,0xb2,0xc4,0xbf,0xe7,0x8f,
		0x19,0x85,0xc5,0xd0,0x5c,0x02,0x54,0x00,0x4c,0xb3,0xeb,0xac,0xe5,0x18,0x3f,0xbc,
		0xff,0x78,0xf4,0x3b,0xe3,0xa2,0x07,0x1f,0x9f,0x7d,0x87,0x26,0x21,0x64,0xcd,0x70,
		0xb6,0x2c,0x17,0x6b,0x9a,0xb2,0xa0,0x01,0xeb,0x5f,0x00,0xd9,0x81,0xa4,0x61,0x27,
		0x2a,0x54,0x0e,0x00,0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82);
}
